@@ -1,11 +1,11 @@
 package List::Compare;
 
-require 5.005_62;
+# require 5.005_62;
 
-$VERSION = 0.09;   # June 16, 2002
+$VERSION = 0.10;   # June 19, 2002
 
 use strict;
-use warnings;
+# use warnings;
 use Carp;
 
 sub new {
@@ -155,8 +155,8 @@ for comparing elements of two lists
 
 =head1 VERSION
 
-This document refers to version 0.09 of List::Compare.  This version was
-released June 16, 2002.
+This document refers to version 0.10 of List::Compare.  This version was
+released June 19, 2002.
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ Set::Scalar - basic set operations
 (L<http://search.cpan.org/doc/JHI/Set-Scalar-1.17/lib/Set/Scalar.pm>)
 
 Set::Bag - bag (multiset) class
-(L<http://search.cpan.org/doc/JHI/Set-Bag-1.17/lib/Set/Bag.pm>)
+(L<http://search.cpan.org/doc/JHI/Set-Bag-1.007/lib/Set/Bag.pm>)
 
 Both of these modules are by Jarkko Hietaniemi <jhi@iki.fi>.  Set::Scalar
 has methods to return the intersection, union, difference and symmetric
@@ -393,7 +393,7 @@ Extend module to do comparisons on more than two lists at a time.
 
 James E. Keenan (jkeen@concentric.net).
 
-Creation date:  May 20, 2002.  Last modification date:  June 16, 2002. 
+Creation date:  May 20, 2002.  Last modification date:  June 19, 2002. 
 Copyright (c) 2002 James E. Keenan.  United States.  All rights reserved. 
 This is free software and may be distributed under the same terms as Perl
 itself.
